"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2024 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Language Identification gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class IdentifyRequest(google.protobuf.message.Message):
    """The top level message sent by the client for the <code>Identify</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data to be identified."""

    @property
    def config(self) -> global___IdentifyConfig:
        """Configuration for the language identification."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: global___IdentifyConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

global___IdentifyRequest = IdentifyRequest

@typing.final
class IdentifyResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Identify</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___LanguageIdentificationResult:
        """Result of language identification."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: global___LanguageIdentificationResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

global___IdentifyResponse = IdentifyResponse

@typing.final
class ListSupportedLanguagesRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>ListSupportedLanguages</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListSupportedLanguagesRequest = ListSupportedLanguagesRequest

@typing.final
class ListSupportedLanguagesResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>ListSupportedLanguages</code>."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORTED_LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def supported_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of supported languages."""

    def __init__(
        self,
        *,
        supported_languages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["supported_languages", b"supported_languages"]) -> None: ...

global___ListSupportedLanguagesResponse = ListSupportedLanguagesResponse

@typing.final
class IdentifyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the languages will be
        identified. If there is less speech in the audio than the specified
        duration, the languages will be identified from the entire audio.
        """

    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Language]:
        """Specify which languages can be used for language identification.
        Choose only from list of supported languages, which can be retrieved at <code>ListSuportedlanguages</code>.
        Choosing desired languages redistributes the probabilities of excluded languages into the rest of languages relative
        to their scores. Excluding a dialect of a language may however result in inaccurate scores for other dialects in cases
        when the excluded dialect would have a probability score close to 1.
        Leaving this field empty is the same as selecting every supported language.
        """

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LanguageGroup]:
        """Create custom groups of languages and assign them a common identifier.
        By defining a group a new entity that encapsulates the group languages is created. This group holds the scores of the
        individual languages as well as their sum.
        One of the use cases for using groups may be grouping individual language dialects into one encapsulating group.  
        Groups of languages mustn't intersect, that means a language can only be part of at most one group.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        languages: collections.abc.Iterable[global___Language] | None = ...,
        groups: collections.abc.Iterable[global___LanguageGroup] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["groups", b"groups", "languages", b"languages", "speech_length", b"speech_length"]) -> None: ...

global___IdentifyConfig = IdentifyConfig

@typing.final
class Language(google.protobuf.message.Message):
    """Message for selecting specific language."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    language_code: builtins.str
    """Language code in RFC 5646 format."""
    def __init__(
        self,
        *,
        language_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language_code", b"language_code"]) -> None: ...

global___Language = Language

@typing.final
class LanguageGroup(google.protobuf.message.Message):
    """Message defining language group.
    Group several languages and assigns them common identifier.
    Defining group produces score for the individual languages as well as for the language groups.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    LANGUAGE_CODES_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    """Identifier of created group.
    This identifier will be used in <code>LanguageIdentificationScore</code>.
    Group identifier must be unique among all groups and languages.
    """
    @property
    def language_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Set of languages forming this group."""

    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        language_codes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["identifier", b"identifier", "language_codes", b"language_codes"]) -> None: ...

global___LanguageGroup = LanguageGroup

@typing.final
class LanguageIdentificationResult(google.protobuf.message.Message):
    """Message representing the result of language identification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    SCORES_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Speech length from which the languageprint was extracted."""

    @property
    def scores(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LanguageIdentificationScore]:
        """List of scores for each selected language and language group.
        This list holds N elements, where:
        N = (number of supported languages) + (number of groups) - (number of languages defined within groups).

        Example: For 140 supported langauges and 2 groups each containing 4 unique langueges
        this field holds: 140 + 2 - (2 * 4) = 134 elements including 132 languages and 2 groups.
        Scores of the individual languages from the groups are embeded within the groups.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        scores: collections.abc.Iterable[global___LanguageIdentificationScore] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["scores", b"scores", "speech_length", b"speech_length"]) -> None: ...

global___LanguageIdentificationResult = LanguageIdentificationResult

@typing.final
class LanguageIdentificationScore(google.protobuf.message.Message):
    """Score for a single language or language group."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _IdentifierType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _IdentifierTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LanguageIdentificationScore._IdentifierType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LANGUAGE: LanguageIdentificationScore._IdentifierType.ValueType  # 0
        """The identifier specifies a single built-in language."""
        GROUP: LanguageIdentificationScore._IdentifierType.ValueType  # 1
        """The identifier specifies a user-defined group of languages."""

    class IdentifierType(_IdentifierType, metaclass=_IdentifierTypeEnumTypeWrapper):
        """Enumeration of supported identifier types."""

    LANGUAGE: LanguageIdentificationScore.IdentifierType.ValueType  # 0
    """The identifier specifies a single built-in language."""
    GROUP: LanguageIdentificationScore.IdentifierType.ValueType  # 1
    """The identifier specifies a user-defined group of languages."""

    IDENTIFIER_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    IDENTIFIER_TYPE_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    """This field contains either a language code (specified by RFC 5646) or a language
    group identifier.
    """
    probability: builtins.float
    """Score for this language or language group.
    The score represents the probability of the input belonging to a particular
    language/group.
    Language group probability is the sum of the probabilities of its languages.
    """
    identifier_type: global___LanguageIdentificationScore.IdentifierType.ValueType
    """This field explicitly identifies the score as belonging to either an individual
    language or a language group.
    """
    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LanguageIdentificationScore]:
        """This field is only set for language groups. 
        Scores for individual languages that this group is comprised of can be found in
        this field.
        """

    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        probability: builtins.float = ...,
        languages: collections.abc.Iterable[global___LanguageIdentificationScore] | None = ...,
        identifier_type: global___LanguageIdentificationScore.IdentifierType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["identifier", b"identifier", "identifier_type", b"identifier_type", "languages", b"languages", "probability", b"probability"]) -> None: ...

global___LanguageIdentificationScore = LanguageIdentificationScore



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'phonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQphonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto\x12\x34phonexia.grpc.technologies.speaker_identification.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x82\x01\n\x0e\x43ompareRequest\x12\x37\n\rvoiceprints_a\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12\x37\n\rvoiceprints_b\x18\x02 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\"?\n\x0f\x43ompareResponse\x12,\n\x06scores\x18\x01 \x01(\x0b\x32\x1c.phonexia.grpc.common.Matrix\"\x91\x01\n\x0e\x45xtractRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x43.phonexia.grpc.technologies.speaker_identification.v1.ExtractConfig\"A\n\rExtractConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"w\n\rExtractResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\nvoiceprint\x18\x02 \x01(\x0b\x32 .phonexia.grpc.common.Voiceprint\"\xa1\x01\n\x0f\x45xtractResponse\x12S\n\x06result\x18\x01 \x01(\x0b\x32\x43.phonexia.grpc.technologies.speaker_identification.v1.ExtractResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb3\x01\n\x14VoiceprintComparison\x12\x9a\x01\n\x07\x43ompare\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.CompareRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.CompareResponse(\x01\x30\x01\x32\xb1\x01\n\x14VoiceprintExtraction\x12\x98\x01\n\x07\x45xtract\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.ExtractRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.ExtractResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speaker_identification.v1.speaker_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMPAREREQUEST']._serialized_start=205
  _globals['_COMPAREREQUEST']._serialized_end=335
  _globals['_COMPARERESPONSE']._serialized_start=337
  _globals['_COMPARERESPONSE']._serialized_end=400
  _globals['_EXTRACTREQUEST']._serialized_start=403
  _globals['_EXTRACTREQUEST']._serialized_end=548
  _globals['_EXTRACTCONFIG']._serialized_start=550
  _globals['_EXTRACTCONFIG']._serialized_end=615
  _globals['_EXTRACTRESULT']._serialized_start=617
  _globals['_EXTRACTRESULT']._serialized_end=736
  _globals['_EXTRACTRESPONSE']._serialized_start=739
  _globals['_EXTRACTRESPONSE']._serialized_end=900
  _globals['_VOICEPRINTCOMPARISON']._serialized_start=903
  _globals['_VOICEPRINTCOMPARISON']._serialized_end=1082
  _globals['_VOICEPRINTEXTRACTION']._serialized_start=1085
  _globals['_VOICEPRINTEXTRACTION']._serialized_end=1262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/language_identification/v1/language_identification.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'phonexia/grpc/technologies/language_identification/v1/language_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSphonexia/grpc/technologies/language_identification/v1/language_identification.proto\x12\x35phonexia.grpc.technologies.language_identification.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x94\x01\n\x0fIdentifyRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12U\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x45.phonexia.grpc.technologies.language_identification.v1.IdentifyConfig\"\xb2\x01\n\x10IdentifyResponse\x12\x63\n\x06result\x18\x01 \x01(\x0b\x32S.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1f\n\x1dListSupportedLanguagesRequest\"=\n\x1eListSupportedLanguagesResponse\x12\x1b\n\x13supported_languages\x18\x01 \x03(\t\"\xec\x01\n\x0eIdentifyConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12R\n\tlanguages\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.language_identification.v1.Language\x12T\n\x06groups\x18\x03 \x03(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.LanguageGroup\"!\n\x08Language\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\";\n\rLanguageGroup\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x16\n\x0elanguage_codes\x18\x02 \x03(\t\"\xb4\x01\n\x1cLanguageIdentificationResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x62\n\x06scores\x18\x02 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\"\xd4\x02\n\x1bLanguageIdentificationScore\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x12\x65\n\tlanguages\x18\x03 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\x12z\n\x0fidentifier_type\x18\x04 \x01(\x0e\x32\x61.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore.IdentifierType\")\n\x0eIdentifierType\x12\x0c\n\x08LANGUAGE\x10\x00\x12\t\n\x05GROUP\x10\x01\x32\x80\x03\n\x16LanguageIdentification\x12\x9d\x01\n\x08Identify\x12\x46.phonexia.grpc.technologies.language_identification.v1.IdentifyRequest\x1aG.phonexia.grpc.technologies.language_identification.v1.IdentifyResponse(\x01\x12\xc5\x01\n\x16ListSupportedLanguages\x12T.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesRequest\x1aU.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.language_identification.v1.language_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IDENTIFYREQUEST']._serialized_start=208
  _globals['_IDENTIFYREQUEST']._serialized_end=356
  _globals['_IDENTIFYRESPONSE']._serialized_start=359
  _globals['_IDENTIFYRESPONSE']._serialized_end=537
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_start=539
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_end=570
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_start=572
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_end=633
  _globals['_IDENTIFYCONFIG']._serialized_start=636
  _globals['_IDENTIFYCONFIG']._serialized_end=872
  _globals['_LANGUAGE']._serialized_start=874
  _globals['_LANGUAGE']._serialized_end=907
  _globals['_LANGUAGEGROUP']._serialized_start=909
  _globals['_LANGUAGEGROUP']._serialized_end=968
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_start=971
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_end=1151
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_start=1154
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_end=1494
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_start=1453
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_end=1494
  _globals['_LANGUAGEIDENTIFICATION']._serialized_start=1497
  _globals['_LANGUAGEIDENTIFICATION']._serialized_end=1881
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2024 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Speaker Identification gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompareRequest(google.protobuf.message.Message):
    """The message sent by the client for the <code>Compare</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_A_FIELD_NUMBER: builtins.int
    VOICEPRINTS_B_FIELD_NUMBER: builtins.int
    @property
    def voiceprints_a(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """First list of voiceprints to be compared."""

    @property
    def voiceprints_b(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """Second list of voiceprints to be compared."""

    def __init__(
        self,
        *,
        voiceprints_a: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
        voiceprints_b: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["voiceprints_a", b"voiceprints_a", "voiceprints_b", b"voiceprints_b"]) -> None: ...

global___CompareRequest = CompareRequest

@typing.final
class CompareResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Compare</code>
    method. It contains comparison matrix of log-likelihood ratio (LLR) scores.
    Comparison matrix containing similarity scores between
    <code>voiceprints_a</code> and <code>voiceprints_b</code>. The element at
    row <code>i</code> and column <code>j</code> corresponds to the comparison
    result between <code>voiceprints_a[i]</code> and
    <code>voiceprints_b[j]</code>.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORES_FIELD_NUMBER: builtins.int
    @property
    def scores(self) -> phonexia.grpc.common.core_pb2.Matrix:
        """The similarity scores are expressed as log-likelihood ratio (LLR) values,
        which fall within the interval of <code>(-inf;+inf)</code>, with higher
        values indicating higher similarity.
        """

    def __init__(
        self,
        *,
        scores: phonexia.grpc.common.core_pb2.Matrix | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scores", b"scores"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["scores", b"scores"]) -> None: ...

global___CompareResponse = CompareResponse

@typing.final
class ExtractRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Extract</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio to extract voiceprints from."""

    @property
    def config(self) -> global___ExtractConfig:
        """Voiceprint extraction configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: global___ExtractConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

global___ExtractRequest = ExtractRequest

@typing.final
class ExtractConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the voiceprint will be
        extracted. If there is less speech in the audio than the specified
        duration, the voiceprint will be extracted from the entire audio.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

global___ExtractConfig = ExtractConfig

@typing.final
class ExtractResult(google.protobuf.message.Message):
    """A voiceprint extraction result."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    VOICEPRINT_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Speech length from which the voiceprint was extracted."""

    @property
    def voiceprint(self) -> phonexia.grpc.common.core_pb2.Voiceprint:
        """Extracted voiceprint."""

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        voiceprint: phonexia.grpc.common.core_pb2.Voiceprint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length", "voiceprint", b"voiceprint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length", "voiceprint", b"voiceprint"]) -> None: ...

global___ExtractResult = ExtractResult

@typing.final
class ExtractResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Extract</code>
    method. It contains the result as zero or more <code>ExtractResult</code>
    messages.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___ExtractResult:
        """Result containing the extracted voiceprint."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: global___ExtractResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

global___ExtractResponse = ExtractResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.speaker_identification.v1 import speaker_identification_pb2 as phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2

GRPC_GENERATED_VERSION = '1.66.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in phonexia/grpc/technologies/speaker_identification/v1/speaker_identification_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class VoiceprintComparisonStub(object):
    """Service that implements voiceprint comparison.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Compare = channel.stream_stream(
                '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison/Compare',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareResponse.FromString,
                _registered_method=True)


class VoiceprintComparisonServicer(object):
    """Service that implements voiceprint comparison.
    """

    def Compare(self, request_iterator, context):
        """Performs synchronous comparison of two voiceprint lists. Each voiceprint
        from one list is compared with each voiceprint from other list. Returns a
        message containing matrix of comparison scores (results of individual
        voiceprint-to-voiceprint comparisons).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VoiceprintComparisonServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Compare': grpc.stream_stream_rpc_method_handler(
                    servicer.Compare,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VoiceprintComparison(object):
    """Service that implements voiceprint comparison.
    """

    @staticmethod
    def Compare(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison/Compare',
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class VoiceprintExtractionStub(object):
    """Service that implements voiceprint extraction.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Extract = channel.stream_unary(
                '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction/Extract',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractResponse.FromString,
                _registered_method=True)


class VoiceprintExtractionServicer(object):
    """Service that implements voiceprint extraction.
    """

    def Extract(self, request_iterator, context):
        """Performs synchronous voiceprint extraction from an audio. Returns a
        result after completely sent and processed audio.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VoiceprintExtractionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Extract': grpc.stream_unary_rpc_method_handler(
                    servicer.Extract,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VoiceprintExtraction(object):
    """Service that implements voiceprint extraction.
    """

    @staticmethod
    def Extract(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction/Extract',
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2024 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Gender Identification gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class IdentifyRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Identify</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_FIELD_NUMBER: builtins.int
    @property
    def voiceprints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """List of voiceprints for the identification."""

    def __init__(
        self,
        *,
        voiceprints: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["voiceprints", b"voiceprints"]) -> None: ...

global___IdentifyRequest = IdentifyRequest

@typing.final
class Score(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_LLR_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    score_llr: builtins.float
    """Log-likelihood ratio score. The LLR provides a quantitative measure of
    how much more likely the data is under one model (gender) compared
    to another.
    A positive LLR suggests that the respective model is more likely to be
    supported by the data than the other model, while the negative LLR suggests
    the opposite.
    """
    probability: builtins.float
    """Decimal value between 0.0 and 1.0, representing a probability."""
    def __init__(
        self,
        *,
        score_llr: builtins.float = ...,
        probability: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["probability", b"probability", "score_llr", b"score_llr"]) -> None: ...

global___Score = Score

@typing.final
class IdentifyResult(google.protobuf.message.Message):
    """A gender identification result. It contains scores for respective genders."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_MALE_FIELD_NUMBER: builtins.int
    SCORE_FEMALE_FIELD_NUMBER: builtins.int
    @property
    def score_male(self) -> global___Score:
        """Score for male."""

    @property
    def score_female(self) -> global___Score:
        """Score for female."""

    def __init__(
        self,
        *,
        score_male: global___Score | None = ...,
        score_female: global___Score | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["score_female", b"score_female", "score_male", b"score_male"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["score_female", b"score_female", "score_male", b"score_male"]) -> None: ...

global___IdentifyResult = IdentifyResult

@typing.final
class IdentifyResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Identify</code>
    method. It contains the result as one or more <code>IdentifyResult</code>
    messages.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IdentifyResult]:
        """Sequential list of results corresponding to sequential list of voiceprints
        in <code>IdentifyRequest</code>.
        """

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___IdentifyResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["results", b"results"]) -> None: ...

global___IdentifyResponse = IdentifyResponse
